% File: respV4.m
% Purpose: response of V4 shape neuron considering weights ci
% Parameters:
%   - neuron: V4 neuron
%   - ndir: number of orientations
%   - ncurv: number of curvatures
% Returns:
%   fct: response of shape neuron in bins
%
% Author: Antonio J. Rodriguez-Sanchez
%
% CVR, Intelligent and Interactive Systems
% Copyright (c) 2012, York University/University of Innsbruck
%
% Permission is granted to copy and distribute this file, for noncommercial
% use, provided (a) this copyright notice is preserved, (b) no attempt
% is made to restrict redistribution of this file, and (c) this file is
% restricted by a compilation copyright.
%
%  All comments concerning this program may be sent to the
%  e-mail address 'Antonio.Rodriguez-Sanchez@uibk.ac.at'
%

function fct = respV4(neuron, ndir, ncurv)

n1 = size(neuron.act,2);
n2 = size(neuron.act,3);
x = -4:8/(ncurv-1):4;
mex = (1-x.^2).*exp(-x.^2/2);
p = -4:4;
x = -4:8/(ncurv-1):4;
mex = 1./(sqrt(2*pi)).*exp(-(p).^2./2)*2.5;
[x y]=meshgrid(-10:10,-10:10);
gauss2d = permute(repmat(1./(2*pi).*exp(-(.1)*(x.^2+y.^2))*6.25,[1 1 ncurv]),[3 1 2]);
h = floor((length(mex)+1)/2);
p = -4:4;
g = 1./(sqrt(2*pi)).*exp(-(p).^2./2)*2.5;

fct = zeros(ncurv,n1,n2);

% Gaussian distances
ma = max(max(max(neuron.act)));
for i=1:n1
  for j=1:n2
    ai = max(1,i-10); bi = min(n1,i+10);
    aj = max(1,j-10); bj = min(n2,j+10);
    g = repmat(neuron.act(:,i,j)/ma,[1 21 21]).*gauss2d;
    fct(:,ai:bi,aj:bj) = max(fct(:,ai:bi,aj:bj),g(:,ai-i+11:bi-i+11,aj-j+11:bj-j+11));
  end
end

